@@ -167,11 +167,15 @@ gfu_common_release_flag_to_string(FwupdReleaseFlags release_flag)
 		/* TRANSLATORS: is not the main firmware stream */
 		return _("Alternate branch");
 	}
-#if FWUPD_CHECK_VERSION(1, 7, 5)
 	if (release_flag == FWUPD_RELEASE_FLAG_IS_COMMUNITY) {
 		/* TRANSLATORS: is not supported by the vendor */
 		return _("Community supported");
 	}
+#if FWUPD_CHECK_VERSION(1, 9, 1)
+	if (release_flag == FWUPD_RELEASE_FLAG_TRUSTED_REPORT) {
+		/* TRANSLATORS: the QA team is someone we trust */
+		return _("Report is trusted");
+	}
 #endif
 
 	/* fall back for unknown types */
@@ -422,63 +426,52 @@ gfu_common_device_flags_to_string(guint64 device_flag)
 		/* TRANSLATORS: it is saved to the users local disk */
 		return _("Device firmware will be saved before installing updates");
 	}
-#if FWUPD_CHECK_VERSION(1, 6, 2)
 	if (device_flag == FWUPD_DEVICE_FLAG_WILDCARD_INSTALL) {
 		/* TRANSLATORS: on some systems certain devices have to have matching versions,
 		 * e.g. the EFI driver for a given network card cannot be different */
 		return _("All devices of the same type will be updated at the same time");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 6, 2)
 	if (device_flag == FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE) {
 		/* TRANSLATORS: some devices can only be updated to a new semver and cannot
 		 * be downgraded or reinstalled with the sexisting version */
 		return _("Only version upgrades are allowed");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 0)
 	if (device_flag == FWUPD_DEVICE_FLAG_UNREACHABLE) {
 		/* TRANSLATORS: the device is currently unreachable, perhaps because it is in a
 		 * lower power state or is out of wireless range */
 		return _("Device is currently unreachable");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 1)
 	if (device_flag == FWUPD_DEVICE_FLAG_AFFECTS_FDE) {
 		/* TRANSLATORS: a volume with full-disk-encryption was found on this machine,
 		 * typically a Windows NTFS partition with BitLocker */
 		return _("May invalidate secrets used to decrypt volumes");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 5)
 	if (device_flag == FWUPD_DEVICE_FLAG_END_OF_LIFE) {
 		/* TRANSLATORS: the vendor is no longer supporting the device */
 		return _("End of life");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 6)
 	if (device_flag == FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD) {
 		/* TRANSLATORS: firmware is verified on-device the payload using strong crypto */
 		return _("Signed payload");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 6)
 	if (device_flag == FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD) {
 		/* TRANSLATORS: firmware payload is unsigned and it is possible to modify it */
 		return _("Unsigned payload");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 8, 11)
 	if (device_flag == FWUPD_DEVICE_FLAG_EMULATED) {
 		/* TRANSLATORS: this device is not actually real */
 		return _("Emulated");
 	}
-#endif
-#if FWUPD_CHECK_VERSION(1, 8, 11)
 	if (device_flag == FWUPD_DEVICE_FLAG_EMULATION_TAG) {
 		/* TRANSLATORS: we're saving all USB events for emulation */
 		return _("Tagged for emulation");
 	}
+#if FWUPD_CHECK_VERSION(1, 9, 3)
+	if (device_flag == FWUPD_DEVICE_FLAG_ONLY_EXPLICIT_UPDATES) {
+		/* TRANSLATORS: device should stay on one firmware version unless the new version
+		 * is explicitly specified */
+		return _("Only explicit updates");
+	}
 #endif
 	if (device_flag == FWUPD_DEVICE_FLAG_UNKNOWN) {
 		return NULL;
@@ -547,41 +540,27 @@ gfu_common_device_icon_from_flag(FwupdDeviceFlags device_flag)
 		return "emblem-shared-symbolic";
 	if (device_flag == FWUPD_DEVICE_FLAG_BACKUP_BEFORE_INSTALL)
 		return "drive-harddisk-symbolic";
-#if FWUPD_CHECK_VERSION(1, 6, 2)
 	if (device_flag == FWUPD_DEVICE_FLAG_WILDCARD_INSTALL)
 		return "edit-copy-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 6, 2)
 	if (device_flag == FWUPD_DEVICE_FLAG_ONLY_VERSION_UPGRADE)
 		return "go-up-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 0)
 	if (device_flag == FWUPD_DEVICE_FLAG_UNREACHABLE)
 		return "network-offline-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 1)
 	if (device_flag == FWUPD_DEVICE_FLAG_AFFECTS_FDE)
 		return "system-lock-screen-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 5)
 	if (device_flag == FWUPD_DEVICE_FLAG_END_OF_LIFE)
 		return "alarm-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 6)
 	if (device_flag == FWUPD_DEVICE_FLAG_SIGNED_PAYLOAD)
 		return "security-high-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 7, 6)
 	if (device_flag == FWUPD_DEVICE_FLAG_UNSIGNED_PAYLOAD)
 		return "security-low-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 8, 11)
 	if (device_flag == FWUPD_DEVICE_FLAG_EMULATED)
 		return "media-playlist-repeat-symbolic";
-#endif
-#if FWUPD_CHECK_VERSION(1, 8, 11)
 	if (device_flag == FWUPD_DEVICE_FLAG_EMULATION_TAG)
 		return "media-playlist-repeat-song-symbolic";
+#if FWUPD_CHECK_VERSION(1, 9, 3)
+	if (device_flag == FWUPD_DEVICE_FLAG_ONLY_EXPLICIT_UPDATES)
+		return "user-info-symbolic";
 #endif
 	if (device_flag == FWUPD_DEVICE_FLAG_UNKNOWN)
 		return "unknown-symbolic";
