@@ -68,9 +68,9 @@ static void
 gfu_main_error_fatal(GfuMain *self, const gchar *text)
 {
 	GtkWidget *w = GTK_WIDGET(gtk_builder_get_object(self->builder, "stack_main"));
-	GtkWidget *leaflet_devices =
-	    GTK_WIDGET(gtk_builder_get_object(self->builder, "leaflet_devices"));
-	gtk_widget_set_visible(GTK_WIDGET(leaflet_devices), FALSE);
+	GtkWidget *split_view_devices =
+	    GTK_WIDGET(gtk_builder_get_object(self->builder, "split_view_devices"));
+	gtk_widget_set_visible(GTK_WIDGET(split_view_devices), FALSE);
 	gtk_stack_set_visible_child_name(GTK_STACK(w), "error");
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "label_error"));
 	adw_status_page_set_description(ADW_STATUS_PAGE(w), text);
@@ -124,7 +124,7 @@ gfu_main_set_label_title(GfuMain *self, const gchar *label_id, const gchar *text
 
 	/* update and display */
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, label_id_title));
-	gtk_label_set_label(GTK_LABEL(w), text);
+	adw_preferences_row_set_title(ADW_PREFERENCES_ROW(w), text);
 	gtk_widget_set_visible(w, TRUE);
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, label_id));
 	gtk_widget_set_visible(w, TRUE);
@@ -253,7 +253,6 @@ gfu_main_device_auto_verify_cb(GObject *source_object, GAsyncResult *res, gpoint
 	gfu_main_set_label(self, "label_device_checksums", _("OK"));
 }
 
-#if FWUPD_CHECK_VERSION(1, 8, 1)
 static gchar *
 gfu_main_device_problem_to_string(GfuMain *self, FwupdDeviceProblem problem)
 {
@@ -298,14 +297,18 @@ gfu_main_device_problem_to_string(GfuMain *self, FwupdDeviceProblem problem)
 		/* TRANSLATORS: lid means "laptop top cover" */
 		return g_strdup(_("Device cannot be used while the lid is closed"));
 	}
+#if FWUPD_CHECK_VERSION(1, 9, 1)
+	if (problem == FWUPD_DEVICE_PROBLEM_IN_USE) {
+		/* TRANSLATORS: device cannot be interrupted, for instance taking a phone call */
+		return g_strdup(_("Device is in use"));
+	}
+#endif
 	return NULL;
 }
-#endif
 
 static gchar *
 gfu_main_device_problems_to_string(GfuMain *self)
 {
-#if FWUPD_CHECK_VERSION(1, 8, 1)
 	g_autoptr(GString) str = g_string_new(NULL);
 
 	/* sanity check */
@@ -331,9 +334,6 @@ gfu_main_device_problems_to_string(GfuMain *self)
 		return NULL;
 	g_string_truncate(str, str->len - 1);
 	return g_string_free(g_steal_pointer(&str), FALSE);
-#else
-	return NULL;
-#endif
 }
 
 static gboolean
@@ -341,8 +341,8 @@ gfu_main_refresh_device_cb(gpointer user_data)
 {
 	GfuMain *self = (GfuMain *)user_data;
 	GtkWidget *w;
-	GtkWidget *leaflet_devices =
-	    GTK_WIDGET(gtk_builder_get_object(self->builder, "leaflet_devices"));
+	GtkWidget *split_view_devices =
+	    GTK_WIDGET(gtk_builder_get_object(self->builder, "split_view_devices"));
 	GPtrArray *vendor_ids = NULL;
 	g_autofree gchar *problems_str = NULL;
 	g_autoptr(GString) attr = g_string_new(NULL);
@@ -352,13 +352,13 @@ gfu_main_refresh_device_cb(gpointer user_data)
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "stack_main"));
 	if (self->device == NULL) {
 		gtk_stack_set_visible_child_name(GTK_STACK(w), "loading");
-		gtk_widget_set_visible(GTK_WIDGET(leaflet_devices), FALSE);
+		gtk_widget_set_visible(GTK_WIDGET(split_view_devices), FALSE);
 		self->refresh_id = 0;
 		return G_SOURCE_REMOVE;
 	}
 
 	gtk_stack_set_visible_child_name(GTK_STACK(w), "main");
-	gtk_widget_set_visible(GTK_WIDGET(leaflet_devices), TRUE);
+	gtk_widget_set_visible(GTK_WIDGET(split_view_devices), TRUE);
 
 	/* set device information */
 	version = g_string_new(fwupd_device_get_version(self->device));
@@ -604,7 +604,8 @@ gfu_main_update_devices_activate_child_cb(gpointer user_data)
 {
 	GfuMain *self = (GfuMain *)user_data;
 	GtkWidget *w;
-	AdwLeaflet *leaflet = ADW_LEAFLET(gtk_builder_get_object(self->builder, "leaflet"));
+	AdwNavigationSplitView *split_view =
+	    ADW_NAVIGATION_SPLIT_VIEW(gtk_builder_get_object(self->builder, "split_view"));
 
 	/* get first device in the list */
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "listbox_devices"));
@@ -613,7 +614,7 @@ gfu_main_update_devices_activate_child_cb(gpointer user_data)
 		return G_SOURCE_REMOVE;
 
 	/* activate the first device */
-	if (!adw_leaflet_get_folded(leaflet))
+	if (!adw_navigation_split_view_get_collapsed(split_view))
 		gtk_widget_activate(w);
 
 	/* never repeat */
@@ -625,7 +626,8 @@ gfu_main_update_devices_cb(GObject *source, GAsyncResult *res, gpointer user_dat
 {
 	GtkWidget *w;
 	GfuMain *self = (GfuMain *)user_data;
-	AdwLeaflet *leaflet = ADW_LEAFLET(gtk_builder_get_object(self->builder, "leaflet"));
+	AdwNavigationSplitView *split_view =
+	    ADW_NAVIGATION_SPLIT_VIEW(gtk_builder_get_object(self->builder, "split_view"));
 	g_autoptr(GError) error = NULL;
 	g_autoptr(GPtrArray) devices = NULL;
 
@@ -672,11 +674,11 @@ gfu_main_update_devices_cb(GObject *source, GAsyncResult *res, gpointer user_dat
 	/* show devices */
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "stack_main"));
 	gtk_stack_set_visible_child_name(GTK_STACK(w), "main");
-	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "leaflet_devices"));
+	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "split_view_devices"));
 	gtk_widget_set_visible(GTK_WIDGET(w), TRUE);
-	adw_leaflet_set_visible_child(leaflet, w);
+	adw_navigation_split_view_set_show_content(split_view, true);
 
-	/* activate the first device once the leaflet has been folded or not */
+	/* activate the first device once the split_view has been collapsed or not */
 	g_idle_add(gfu_main_update_devices_activate_child_cb, self);
 }
 
@@ -1272,13 +1274,6 @@ gfu_main_release_row_button_clicked_cb(GfuReleaseRow *row, GfuMain *self)
 	gfu_main_release_install_response(self);
 }
 
-static void
-gfu_main_button_back_cb(GtkWidget *widget, GfuMain *self)
-{
-	AdwLeaflet *leaflet = ADW_LEAFLET(gtk_builder_get_object(self->builder, "leaflet"));
-	adw_leaflet_navigate(leaflet, ADW_NAVIGATION_DIRECTION_BACK);
-}
-
 static void
 gfu_main_device_verify_cb(GObject *source_object, GAsyncResult *res, gpointer user_data)
 {
@@ -1404,37 +1399,43 @@ gfu_main_about_activated_cb(GSimpleAction *action, GVariant *parameter, gpointer
 	GfuMain *self = (GfuMain *)user_data;
 	GList *windows;
 	GtkWindow *parent = NULL;
-	const gchar *authors[] = {"Richard Hughes", "Andrew Schwenn", NULL};
+	GtkWidget *about = NULL;
+	const gchar *developers[] = {"Richard Hughes", "Andrew Schwenn", NULL};
+	const gchar *artists[] = {"Jakub Steiner", NULL};
 	const gchar *copyright = "Copyright \xc2\xa9 2019 Richard Hughes";
 
 	windows = gtk_application_get_windows(GTK_APPLICATION(self->application));
 	if (windows)
 		parent = windows->data;
 
-	gtk_show_about_dialog(parent,
-			      "title",
-			      /* TRANSLATORS: the title of the about window */
-			      _("About GNOME Firmware"),
-			      "program-name",
-			      /* TRANSLATORS: the application name for the about UI */
-			      _("GNOME Firmware"),
-			      "authors",
-			      authors,
-			      "comments",
-			      /* TRANSLATORS: one-line description for the app */
-			      _("Install firmware on devices"),
-			      "copyright",
-			      copyright,
-			      "license-type",
-			      GTK_LICENSE_GPL_2_0,
-			      "logo-icon-name",
-			      "org.gnome.Firmware",
-			      "translator-credits",
-			      /* TRANSLATORS: you can put your name here :) */
-			      _("translator-credits"),
-			      "version",
-			      VERSION,
-			      NULL);
+	about = g_object_new(ADW_TYPE_ABOUT_WINDOW,
+			     "transient-for",
+			     GTK_WINDOW(parent),
+			     /* TRANSLATORS: the application name for the about UI */
+			     "application-name",
+			     _("GNOME Firmware"),
+			     "developers",
+			     developers,
+			     "copyright",
+			     copyright,
+			     "license-type",
+			     GTK_LICENSE_GPL_2_0,
+			     "application-icon",
+			     "org.gnome.Firmware",
+			     "translator-credits",
+			     /* TRANSLATORS: you can put your name here :) */
+			     _("translator-credits"),
+			     "version",
+			     VERSION,
+			     "issue-url",
+			     "https://gitlab.gnome.org/World/gnome-firmware/-/issues",
+			     "support-url",
+			     "https://gitlab.gnome.org/World/gnome-firmware/-/issues",
+			     "artists",
+			     artists,
+			     NULL);
+
+	gtk_window_present(GTK_WINDOW(about));
 }
 
 static void
@@ -1578,7 +1579,7 @@ gfu_main_release_row_selected_cb(GtkListBox *box, GtkListBoxRow *row, GfuMain *s
 {
 	FwupdRelease *release = gfu_release_row_get_release(GFU_RELEASE_ROW(row));
 	GtkWidget *w;
-	GtkWidget *leaflet = GTK_WIDGET(gtk_builder_get_object(self->builder, "leaflet"));
+	GtkWidget *split_view = GTK_WIDGET(gtk_builder_get_object(self->builder, "split_view"));
 
 	g_set_object(&self->release, release);
 	gfu_main_refresh_release(self);
@@ -1588,8 +1589,8 @@ gfu_main_release_row_selected_cb(GtkListBox *box, GtkListBoxRow *row, GfuMain *s
 
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "window_release"));
 	gtk_window_set_default_size(GTK_WINDOW(w),
-				    gtk_widget_get_width(leaflet) * 85 / 100,
-				    gtk_widget_get_height(leaflet) * 60 / 100);
+				    gtk_widget_get_width(split_view) * 85 / 100,
+				    gtk_widget_get_height(split_view) * 60 / 100);
 	gtk_window_present(GTK_WINDOW(w));
 }
 
@@ -1620,13 +1621,14 @@ gfu_main_refresh_releases(GfuMain *self)
 static void
 gfu_main_device_row_selected_cb(GtkListBox *box, GtkListBoxRow *row, GfuMain *self)
 {
-	AdwLeaflet *leaflet = ADW_LEAFLET(gtk_builder_get_object(self->builder, "leaflet"));
+	AdwNavigationSplitView *split_view =
+	    ADW_NAVIGATION_SPLIT_VIEW(gtk_builder_get_object(self->builder, "split_view"));
 	FwupdDevice *device;
 
 	if (row == NULL)
 		return;
 
-	adw_leaflet_navigate(leaflet, ADW_NAVIGATION_DIRECTION_FORWARD);
+	adw_navigation_split_view_set_show_content(split_view, true);
 
 	device = gfu_device_row_get_device(GFU_DEVICE_ROW(row));
 	g_set_object(&self->device, device);
@@ -1736,16 +1738,6 @@ gfu_main_infobar_response_cb(GtkInfoBar *infobar, gint response_id, gpointer use
 		gtk_info_bar_set_revealed(infobar, FALSE);
 }
 
-static void
-gfu_main_leaflet_notify_folded_cb(AdwLeaflet *leaflet, GParamSpec *pspec, GfuMain *self)
-{
-	GtkWidget *w;
-	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "listbox_devices"));
-	gtk_list_box_set_selection_mode(GTK_LIST_BOX(w),
-					adw_leaflet_get_folded(leaflet) ? GTK_SELECTION_NONE
-									: GTK_SELECTION_SINGLE);
-}
-
 static void
 gfu_main_client_connect_cb(GObject *source, GAsyncResult *res, gpointer user_data)
 {
@@ -1767,10 +1759,8 @@ gfu_main_client_connect_cb(GObject *source, GAsyncResult *res, gpointer user_dat
 	fwupd_client_set_feature_flags_async(
 	    self->client,
 	    FWUPD_FEATURE_FLAG_FDE_WARNING | FWUPD_FEATURE_FLAG_SWITCH_BRANCH |
-#if FWUPD_CHECK_VERSION(1, 8, 1)
-		FWUPD_FEATURE_FLAG_SHOW_PROBLEMS |
-#endif
-		FWUPD_FEATURE_FLAG_REQUESTS | FWUPD_FEATURE_FLAG_UPDATE_ACTION,
+		FWUPD_FEATURE_FLAG_SHOW_PROBLEMS | FWUPD_FEATURE_FLAG_REQUESTS |
+		FWUPD_FEATURE_FLAG_UPDATE_ACTION,
 	    self->cancellable,
 	    gfu_main_set_feature_flags_cb,
 	    self);
@@ -1806,8 +1796,6 @@ gfu_main_startup_cb(GApplication *application, GfuMain *self)
 	g_signal_connect(w, "clicked", G_CALLBACK(gfu_main_device_verify_clicked_cb), self);
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "button_verify_update"));
 	g_signal_connect(w, "clicked", G_CALLBACK(gfu_main_device_verify_update_cb), self);
-	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "button_back"));
-	g_signal_connect(w, "clicked", G_CALLBACK(gfu_main_button_back_cb), self);
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "button_infobar_enable_lvfs"));
 	g_signal_connect(w, "clicked", G_CALLBACK(gfu_main_enable_lvfs_cb), self);
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "listbox_devices"));
@@ -1818,8 +1806,6 @@ gfu_main_startup_cb(GApplication *application, GfuMain *self)
 	g_signal_connect(w, "close", G_CALLBACK(gfu_main_infobar_close_cb), self);
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "infobar_enable_lvfs"));
 	g_signal_connect(w, "response", G_CALLBACK(gfu_main_infobar_response_cb), self);
-	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "leaflet"));
-	g_signal_connect(w, "notify::folded", G_CALLBACK(gfu_main_leaflet_notify_folded_cb), self);
 
 	w = GTK_WIDGET(gtk_builder_get_object(self->builder, "window_release"));
 	g_signal_connect(ADW_WINDOW(w), "close-request", G_CALLBACK(gtk_widget_hide), self);
@@ -1959,11 +1945,7 @@ main(int argc, char **argv)
 	self->post_requests = g_ptr_array_new_with_free_func((GDestroyNotify)g_object_unref);
 
 	/* ensure single instance */
-#if GLIB_CHECK_VERSION(2, 74, 0)
 	self->application = adw_application_new("org.gnome.Firmware", G_APPLICATION_DEFAULT_FLAGS);
-#else
-	self->application = adw_application_new("org.gnome.Firmware", G_APPLICATION_FLAGS_NONE);
-#endif
 	g_signal_connect(self->application, "startup", G_CALLBACK(gfu_main_startup_cb), self);
 	g_signal_connect(self->application, "activate", G_CALLBACK(gfu_main_activate_cb), self);
 	/* set verbose? */
